@@ -183,13 +183,35 @@ static void convert_digit_sequence(NJDNode * start, NJDNode * end)
    int size = 0;
    int have = 0;
 
-   if (get_digit_sequence_score(start, end) < 0)
-      return;
-
    for (node = start; node != end->next; node = node->next)
       size++;
    if (size <= 1)
       return;
+
+   if (get_digit_sequence_score(start, end) < 0) {
+      for (node = start, size = 0; node != end->next; node = node->next) {
+         if (strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_ZERO) == 0) {
+            NJDNode_set_pron(node, NJD_SET_DIGIT_ZERO_AFTER_DP);
+            NJDNode_set_mora_size(node, 2);
+         } else if (strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_TWO) == 0) {
+            NJDNode_set_pron(node, NJD_SET_DIGIT_TWO_AFTER_DP);
+            NJDNode_set_mora_size(node, 2);
+         } else if (strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_FIVE) == 0) {
+            NJDNode_set_pron(node, NJD_SET_DIGIT_FIVE_AFTER_DP);
+            NJDNode_set_mora_size(node, 2);
+         }
+         NJDNode_set_chain_rule(node, NULL);
+         if (size % 2 == 0) {
+            NJDNode_set_chain_flag(node, 0);
+         } else {
+            NJDNode_set_chain_flag(node, 1);
+            NJDNode_set_acc(node->prev, 3);
+         }
+         size++;
+      }
+      return;
+   }
+
    index = size % 4;
    if (index == 0)
       index = 4;
@@ -341,55 +363,23 @@ void njd_set_digit(NJD * njd)
    if (njd->head == NULL)
       return;
 
-   /* convert feature of a decimal point */
-   find = 0;
-   for (node = njd->head->next; node != NULL; node = node->next) {
-      if (NJDNode_get_string(node) != NULL) {
-         if (node->next != NULL &&
-             (strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_TEN1) == 0 ||
-              strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_TEN2) == 0) &&
-             strcmp(NJDNode_get_pos_group1(node->prev), NJD_SET_DIGIT_KAZU) == 0 &&
-             strcmp(NJDNode_get_pos_group1(node->next), NJD_SET_DIGIT_KAZU) == 0) {
-            NJDNode_load(node, NJD_SET_DIGIT_TEN_FEATURE);
-            NJDNode_set_chain_flag(node, 1);
-            find = 1;
-            if (NJDNode_get_string(node->prev) != NULL) {
-               if (strcmp(NJDNode_get_string(node->prev), NJD_SET_DIGIT_ZERO) == 0) {
-                  NJDNode_set_pron(node->prev, NJD_SET_DIGIT_ZERO_BEFORE_DP);
-                  NJDNode_set_mora_size(node->prev, 2);
-               } else if (strcmp(NJDNode_get_string(node->prev), NJD_SET_DIGIT_TWO) == 0) {
-                  NJDNode_set_pron(node->prev, NJD_SET_DIGIT_TWO_BEFORE_DP);
-                  NJDNode_set_mora_size(node->prev, 2);
-               } else if (strcmp(NJDNode_get_string(node->prev), NJD_SET_DIGIT_FIVE) == 0) {
-                  NJDNode_set_pron(node->prev, NJD_SET_DIGIT_FIVE_BEFORE_DP);
-                  NJDNode_set_mora_size(node->prev, 2);
-               }
-            }
-         } else if (find > 0) {
-            if (strcmp(NJDNode_get_pos_group1(node), NJD_SET_DIGIT_KAZU) == 0) {
-               if (strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_ZERO) == 0) {
-                  NJDNode_set_pron(node, NJD_SET_DIGIT_ZERO_AFTER_DP);
-                  NJDNode_set_mora_size(node, 2);
-               } else if (node->next == NULL ||
-                          (node->next != NULL &&
-                           strcmp(NJDNode_get_pos_group2(node->next),
-                                  NJD_SET_DIGIT_JOSUUSHI) != 0)) {
-                  if (strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_TWO) == 0) {
-                     NJDNode_set_pron(node, NJD_SET_DIGIT_TWO_AFTER_DP);
-                     NJDNode_set_mora_size(node, 2);
-                  } else if (strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_FIVE) == 0) {
-                     NJDNode_set_pron(node, NJD_SET_DIGIT_FIVE_AFTER_DP);
-                     NJDNode_set_mora_size(node, 2);
-                  }
-               }
-               if (find % 2 == 1)
-                  NJDNode_set_chain_flag(node, 0);
-               else
-                  NJDNode_set_chain_flag(node, 1);
-               find++;
-            } else {
-               find = 0;
-            }
+   for (node = njd->head->next; node != NULL && node->next != NULL; node = node->next) {
+      if (NJDNode_get_string(node) != NULL && NJDNode_get_string(node->prev) != NULL
+          && (strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_TEN1) == 0
+              || strcmp(NJDNode_get_string(node), NJD_SET_DIGIT_TEN2) == 0)
+          && strcmp(NJDNode_get_pos_group1(node->prev), NJD_SET_DIGIT_KAZU) == 0
+          && strcmp(NJDNode_get_pos_group1(node->next), NJD_SET_DIGIT_KAZU) == 0) {
+         NJDNode_load(node, NJD_SET_DIGIT_TEN_FEATURE);
+         NJDNode_set_chain_flag(node, 1);
+         if (strcmp(NJDNode_get_string(node->prev), NJD_SET_DIGIT_ZERO) == 0) {
+            NJDNode_set_pron(node->prev, NJD_SET_DIGIT_ZERO_BEFORE_DP);
+            NJDNode_set_mora_size(node->prev, 2);
+         } else if (strcmp(NJDNode_get_string(node->prev), NJD_SET_DIGIT_TWO) == 0) {
+            NJDNode_set_pron(node->prev, NJD_SET_DIGIT_TWO_BEFORE_DP);
+            NJDNode_set_mora_size(node->prev, 2);
+         } else if (strcmp(NJDNode_get_string(node->prev), NJD_SET_DIGIT_FIVE) == 0) {
+            NJDNode_set_pron(node->prev, NJD_SET_DIGIT_FIVE_BEFORE_DP);
+            NJDNode_set_mora_size(node->prev, 2);
          }
       }
    }
